
package codemaptournament;

import java.text.DecimalFormat;

/**
 * The Frame data type has a value in integer frames and a display
 * of the M:SS variety
 * @author Paul
 */
public class Frames extends DisplayAndValue implements Comparable<Frames> {
    /** Global flag to use the value not display of the frames - used in prior program */
    static boolean showRawFrames = false;
    /** whether to show decimal seconds or not */
    static final boolean showTenthsOfSeconds = false;

    static DecimalFormat formatSecsDecimal = new DecimalFormat("00.0");
    static DecimalFormat formatSecs = new DecimalFormat("00");
    public Frames(int frames) {
        super(
            showTenthsOfSeconds ? framesToTimeDecimal(frames) : framesToTime(frames), // text (precompute)
            frames // value
        );
    }

    public int compareTo(Frames other) {
        return (Integer) value - (Integer) other.value;
    }

    @Override
    public String toString() {
        if (showRawFrames) return value.toString();
        return super.toString();
    }
    
    /*
     * format frames sorta like the score viewer does, truncate to tenths of seconds
     * @return string like 45:01.8
     */
    static String framesToTimeDecimal(int frames) {
        double secs = frames / 30.0;
        double min = Math.floor(secs / 60.0);
        double dsecs = Math.floor((secs - min * 60.0) * 10.0) / 10.0;
        return (int)min + ":" + formatSecsDecimal.format(dsecs);
    }
    /*
     * format frames like the game does, truncate to seconds
     * @return string like 45:01
     */
    static String framesToTime(int frames) {
        double secs = frames / 30.0;
        double min = Math.floor(secs / 60.0);
        secs = Math.floor(secs - 60.0 * min);
        return (int)min + ":" + formatSecs.format(secs);
    }
    /*
     * format frames exactly as the score viewer does, truncate to tenths of seconds
     * @return string like 45 min 1.8 sec
     */
    static String framesToScoreViewerTime(int frames) {
        double secs = frames / 30.0;
        double min = Math.floor(secs / 60.0);
        double dsecs = Math.floor((secs - min * 60.0) * 10.0) / 10.0;
        return (int)min + " min " + dsecs + " sec";
    }
}
