package codemaptournament;

/**
 * formatting tables etc using BB codes
 * @author Paul
 */
public class BBCode {
    public static String COLOR_MAPNAME = "red";
    public static String COLOR_SIZE = "blue";
    public static String COLOR_COMPLEXITY = "green";

    public static String COLOR_GRAVITYDIR = "brown";
    public static String COLOR_BUILDDIR = "teal";
    public static String COLOR_HASEXPERIMENTALS = "purple";

    // See http://knucklecracker.com/forums/index.php?topic=10374.msg68222#msg68222 for discussion on colors
    public static String COLOR_GOLD = "GoldenRod";
    public static String COLOR_SILVER = "#A0A0A0";
    public static String COLOR_BRONZE = "#8C7853"; // #CD7F32 = bronze for wiki, #8C7853 = TP CW2, "#B8860B" = UK CW1
    public static String[] VICTOR_COLORS = {BBCode.COLOR_GOLD, BBCode.COLOR_SILVER, BBCode.COLOR_BRONZE};

    /** whether to right-justify personal times to make them line up better */
    public static boolean RIGHT_JUSTIFY_PERSONAL_TIMES = true;
    /** whether to add spaces to the table format to make it more readable */
    public static boolean INDENT_TABLE = true;
    /** whether to make map names have the same color as the header, COLOR_MAPNAME */
    public static boolean COLOR_MAP_NAMES = true;

    public static String table(String[][] table) {
        StringBuilder sb = new StringBuilder();
        final String indent = "    ";

        sb.append("[table]\n");
        for (String[] row : table) {
            sb.append("[tr]");
            if (INDENT_TABLE) sb.append("\n");
            for (String elem : row) {
                if (INDENT_TABLE) sb.append(indent);
                sb.append("[td]");
                sb.append(elem);
                sb.append("[/td]");
                if (INDENT_TABLE) sb.append("\n");
            }
            sb.append("[/tr]\n");
        }
        sb.append("[/table]\n");

        return sb.toString();
    }

    public static String bold(String s) {
        return "[b]" + s + "[/b]";
    }

    public static String italic(String s) {
        return "[i]" + s + "[/i]";
    }

    public static String color(String s, String colorname) {
        return "[color=" + colorname + "]" + s + "[/color]";
    }

    /** this is not currently used because glows don't actually look that nice */
    public static String glow(String s, String colorname) {
        return "[glow=" + colorname + ",2,300]" + s + "[/glow]";
    }

    public static String right(String s) {
        return "[right]" + s + "[/right]";
    }

    /** size string is something like "11pt" */
    public static String size(String s, String size) {
        return "[size=" + size + "]" + s + "[/size]";
    }

    /** 0->gold, 1->silver, 2->bronze, anything else ->"" */
    public static String getVictorColor(int rank) {
        return rank < VICTOR_COLORS.length ? VICTOR_COLORS[rank] : "";

    }
}
