package codemaptournament;

import java.util.Comparator;
import org.apache.commons.collections.comparators.ComparatorChain;

/**
 * records one entry in the high score chart: user, total score, # games played
 * @author Paul
 */
public class HighScoreEntry {

    public String user;
    public int totalScore;
    public Frames totalTime;
    public int gamesPlayed;
    public boolean playedAllGames;

    public HighScoreEntry(String user, int totalScore, Frames totalTime, int gamesPlayed, boolean playedAllGames) {
        this.user = user;
        this.totalScore = totalScore;
        this.totalTime = totalTime;
        this.gamesPlayed = gamesPlayed;
        this.playedAllGames = playedAllGames;
    }

    static class CompareByUser implements Comparator<HighScoreEntry> {

        public int compare(HighScoreEntry o1, HighScoreEntry o2) {
            return o1.user.compareToIgnoreCase(o2.user);
        }
    }

    static class CompareByScore implements Comparator<HighScoreEntry> {

        public int compare(HighScoreEntry o1, HighScoreEntry o2) {
            return o1.totalScore - o2.totalScore;
        }
    }
    
    static class CompareByTime implements Comparator<HighScoreEntry> {

        public int compare(HighScoreEntry o1, HighScoreEntry o2) {
            System.out.println("comparing by total time - you should double-check the results");
            return o1.totalTime.compareTo(o2.totalTime);
        }
    }

    static class CompareByGamesPlayed implements Comparator<HighScoreEntry> {

        public int compare(HighScoreEntry o1, HighScoreEntry o2) {
            return o1.gamesPlayed - o2.gamesPlayed;
        }
    }

    static final Comparator tournamentComparator;

    static {
        ComparatorChain c = new ComparatorChain();
        c.addComparator(new HighScoreEntry.CompareByGamesPlayed(), true); // high first
        c.addComparator(new HighScoreEntry.CompareByScore(), true); // high first
        c.addComparator(new CompareByTime(), false); // low first
        c.addComparator(new HighScoreEntry.CompareByUser(), false); // low first
        tournamentComparator = c;
    }
}
