package codemaptournament;

import org.apache.commons.codec.digest.DigestUtils;

/**
 * Holds parameters describing a Code Mission
 * @author Paul
 */
public class Mission {
    public final String code;
    public final int size, complexity;
    public final String gameUID;

    public static final String DEFAULT_CODE = "";
    public static final int DEFAULT_SIZE = 0;
    public static final String [] sizeStrings = {
        "Small", "Medium", "Large"
    };
    public static final int DEFAULT_COMPLEXITY = 0;
    public static final String [] complexityStrings = {
        "Low", "Medium", "High"
    };
    public static final Mission DEFAULT_MISSION = new Mission(DEFAULT_CODE, DEFAULT_SIZE, DEFAULT_COMPLEXITY);

    public Mission(String code, int size, int complexity) {
        this.code = code;
        this.size = size;
        this.complexity = complexity;
        gameUID = "procedural" + getSeedFromString(code) + "-" + size + complexity;
    }

    public static int getSizeFromString(String s) {
        for (int i = 0; i < sizeStrings.length; i++) {
            if (sizeStrings[i].equalsIgnoreCase(s)) return i;
        }
        return DEFAULT_SIZE;
    }

    public static int getComplexityFromString(String s) {
        for (int i = 0; i < complexityStrings.length; i++) {
            if (complexityStrings[i].equalsIgnoreCase(s)) return i;
        }
        return DEFAULT_COMPLEXITY;
    }

    @Override
    public String toString() {
        return "Mission{" + "code=" + code + ",size=" + size + ",complexity=" + complexity + ",gameUID=" + gameUID + '}';
    }


    /**
     * Hash a string into a four-byte number
     * I'm using longs since ints in java are signed, and it needs a uint
     * @param str
     * @return
     */
    public static long getSeedFromString(String str) {
        str = str.toLowerCase().trim();
        String hex = DigestUtils.md5Hex(str).substring(0, 8);
        return Long.parseLong(hex, 16);
    }
}
