package codemaptournament;

import java.io.File;
import java.io.FileNotFoundException;
import java.io.FileWriter;
import java.io.IOException;
import java.util.ArrayList;
import java.util.List;
import java.util.Scanner;
import java.util.logging.Level;
import java.util.logging.Logger;

/**
 * persists missiontablemodel state using a file with tab-separated mission data
 * @author Paul
 */
public class SaveLoad {
    private static final String ROW_SEP = "\n";
    private static final String COL_SEP = "\t";
    private static final String MISSION_FILENAME = ".missions";
    private static final File missionFile = new File(MISSION_FILENAME);

    /**
     * Write the mission data in the model to a file.
     * Silently ignores any errors.
     * "by coincidence" the format is the same as plain table.
     * @param model
     */
    public static void save(MissionTableModel model) {
        FileWriter writer = null;
        try {
//            System.out.println("writing to file " + missionFile.getAbsolutePath());
            final List<Mission> missionList = model.getMissionList();
            writer = new FileWriter(missionFile);
            for (int row = 0; row < missionList.size(); row++) {
                final Mission m = missionList.get(row);
                if (row > 0) writer.write(ROW_SEP);
                writer.write(m.code.replaceAll(ROW_SEP, "").replaceAll(COL_SEP, ""));
                writer.write(COL_SEP);
                writer.write(Mission.sizeStrings[m.size]);
                writer.write(COL_SEP);
                writer.write(Mission.complexityStrings[m.complexity]);
//                System.out.println("wrote Mission(" + m.code + "," + m.size + "," + m.complexity + ")");
            }
        } catch (Exception ex) {
            Logger.getLogger(SaveLoad.class.getName()).log(Level.WARNING, null, ex);
        } finally {
            try {
                if (writer != null) writer.close();
            } catch (Exception ex) {
                Logger.getLogger(SaveLoad.class.getName()).log(Level.WARNING, null, ex);
            }
        }
    }

    /**
     * Read the memory file and load missions there into the model.
     * Any parse error results in the default values being used (Mission.DEFAULT_X)
     * @param model
     */
    public static void load(MissionTableModel model) {
        List<Mission> missions = new ArrayList<Mission>();
        try {
            Scanner rowScanner = new Scanner(missionFile);
            rowScanner.useDelimiter(ROW_SEP);
            while (missions.size() < MissionTableModel.NUM_ROWS && rowScanner.hasNext()) {
                String row = rowScanner.next();
                Scanner colScanner = new Scanner(row);
                colScanner.useDelimiter(COL_SEP);
                String code = Mission.DEFAULT_CODE;
                int size = Mission.DEFAULT_SIZE;
                int complexity = Mission.DEFAULT_COMPLEXITY;
                if (colScanner.hasNext()) {
                    if (!row.startsWith(COL_SEP)) // handle blank code properly
                        code = colScanner.next();
                }
                if (colScanner.hasNext()) {
                    size = Mission.getSizeFromString(colScanner.next());
                }
                if (colScanner.hasNext()) {
                    complexity = Mission.getComplexityFromString(colScanner.next());
                }
                Mission m = new Mission(code, size, complexity);
//                System.out.println("row `" + row + "' => " + m);
                missions.add(m);
            }
        } catch (IOException ex) {
            // no problem
        }
        while (missions.size() < MissionTableModel.NUM_ROWS)
            missions.add(Mission.DEFAULT_MISSION);

        model.setMissionList(missions);
    }
}

